#
# spec file for package lbdb
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2011 Red Hat, Inc
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugzilla.redhat.com
#

Name:           lbdb
Summary:        Address Database for mutt
Version:        0.38
Release:        2%{?dist}
License:        GPLv2+
Url:            http://www.spinnaker.de/lbdb/
Group:          Applications/Communications
Source:         http://www.spinnaker.de/debian/lbdb_%{version}.tar.gz
# change default modules list
Patch:          lbdb.rc.diff
# fix path of evolution-addressbook-export
Patch1:         lbdb-0.38-evolution.diff
# fix hostname lookup if multiple domains are listed in resolv.conf
Patch2:         lbdb-hostname.diff
Requires:       perl(Net::LDAP)
Requires:       perl(Getopt::Long)

%description
The Little Brother's Database (lbdb) consists of a set of small tools
that collect mail addresses from several sources and offer these
addresses to the external query feature of the Mutt mail reader.


%prep
%setup -q -n lbdb-%{version}
%patch -p0
%patch1 -p1
%patch2 -p1


%build
export EVOLUTION_ADDRESSBOOK_EXPORT='/usr/libexec/evolution/*/evolution-addressbook-export'
# lbdb uses libdir in most of its helper programs to find the absolute path
# to these binaries, that's why it's forcefully set to %_libexecdir/lbdb.
# Another option would be to s/libdir/libexecdir in the helpers, but there
# are about 15 programs to patch, so this approach is easier.
%configure --libdir=%{_libexecdir}/lbdb
make %{?_smp_mflags}


%install
BUILD_ROOT=${RPM_BUILD_ROOT} make \
        install_prefix=${RPM_BUILD_ROOT} \
        sysconfdir=%{_sysconfdir} \
        mandir=%{_mandir} \
        libdir=%{_libexecdir}/lbdb \
        install


%files
%doc README COPYING INSTALL TODO
%config(noreplace) %{_sysconfdir}/*
%{_bindir}/*
%{_libexecdir}/lbdb/*
%dir %{_libexecdir}/lbdb
%doc %{_mandir}/man?/*

%changelog
* Sun Mar 04 2012 Christophe Fergeau <cfergeau@redhat.com> - 0.38-2
- add %%{?dist} in release
- remove use of BuildRoot:
- remove use of %%defattr
- remove usage instruction from %%description
- comment patches

* Mon Sep 19 2011 Christophe Fergeau <cfergeau@redhat.com> - 0.38-1
- new version 0.38
  * adapt the spec file for fedora use

* Tue Feb  8 2011 lnussel@suse.de
- Suggest perl(Net::LDAP) (bnc#669969)
* Wed May 19 2010 lnussel@suse.de
- new version 0.37
  * Fix bashisms in m_bbdb
  * Fix query shell functions to catch non-zero exit status in case they
    get invoked in set -e context.
  * m_evolution: support line breaks and long lines.
  * Fix documentation concerning the quotes on lbdbq call
- fix path to evolution-addressbook-export
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Thu Oct  2 2008 lnussel@suse.de
- new version 0.36
  * Remove duplicate "See also: mutt" from lbdbq.man.
  * Update configure using autconf 2.61.
  * Apply charset conversation patch by Peter Colberg based on code by
    Tobias Schlemmer.
  * Remove duplicate declaration of $ignorant.
  * Handle mail addresses in mutt_ldap_query correct. Thanks to Colin
    Watson <cjwatson@debian.org> for providing a patch.
  * Mention ldapi URIs in mutt_ldap_query man page.
  * Protect "make distclean" by checking whether makefile exists.
  * Upgrade to Standards-Version 3.8.0:
  - Fix Homepage header in control file.
  * Add copyright holders to debian/copyright file.
  * Remove outdated override.Lintian.
* Fri Aug 10 2007 lnussel@suse.de
- new version 0.35.1
  * supports ldaps
* Wed May 16 2007 lnussel@suse.de
- new version 0.34
  * vcquery: avoid free() on unallocated memory if fullname is not set.
  * vcquery: Use value of concatenated N fields if FN field is missing.
- fix hostname lookup if multiple domains are listed in resolv.conf
* Mon Oct 16 2006 lnussel@suse.de
- new version 0.33
  * Add SORT_OUTPUT=reverse_comment to do reverse sort by the third column
    (most recent m_inmail timestamp at the top).
  * Comment out LDAP_NICKS in lbdb.rc because this should only be an
    example and if it is set there it overrides other LDAP settings
* Thu Aug 24 2006 lnussel@suse.de
- new version 0.32
- fix path to evolution-addressbook-export
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon May  9 2005 lnussel@suse.de
- update to version 0.30
* Fri Feb 27 2004 lnussel@suse.de
- run configure similar to the original debian package to reduce
  neededforbuild and to fix evolution addressbook query
- add gpg to default address query methods
* Thu Feb 26 2004 lnussel@suse.de
- update to version 0.29
* Sun Feb  8 2004 lnussel@suse.de
- update to version 0.28.2
- use %%optflags, fix aliasing problems
* Wed Feb 12 2003 lnussel@suse.de
- new version 0.26.2
  * new ldap option $ignorant
  * support for multiple abook address books
* Fri Aug 16 2002 ro@suse.de
- removed emtpy post/postun scripts (#17916)
* Thu Apr 25 2002 lnussel@suse.de
- new version 0.26
- now uses m_getent instead of m_passwd (lbdb.rc.dif)
- moved files from %%{_prefix}/lib to %%{_libdir}/lbdb
* Tue Jul 24 2001 lnussel@suse.de
- new version 0.25
* Tue Mar 20 2001 lnussel@suse.de
- new version 0.24
- added finger to neededforbuild
* Wed Feb  7 2001 lnussel@suse.de
- new version 0.23
- neededforbuild: ypbind -> yp-tools
* Thu Nov 30 2000 ro@suse.de
- neededforbuild: ypclient -> ypbind
* Thu Oct 12 2000 lnussel@suse.de
- new version 0.21.1
- cleaned up spec file
- changed Group to Applications/Mail
* Tue Aug 29 2000 lnussel@suse.de
- initial check in
